@@ -131,7 +131,9 @@ def setup_workflow():
                           output_collections=[{'scope': 'pseudo_dataset', 'name': 'pseudo_output_collection#3'}],
                           log_collections=[], dependency_map=taskN3.dependencies, task_name=taskN3.name, task_queue=task_queue)
 
-    workflow = Workflow()
+    pending_time = 0.5
+    # pending_time = None
+    workflow = Workflow(pending_time=pending_time)
     workflow.add_work(work1)
     workflow.add_work(work2)
     workflow.add_work(work3)
